@@ -69,6 +69,8 @@ sub new { die "This class is a role for use by packages such as Template::Alloy"
 sub play_tree {
     my ($self, $tree, $out_ref) = @_;
 
+    return $self->stream_tree($tree) if $self->{'STREAM'};
+
     # node contains (0: DIRECTIVE,
     #                1: start_index,
     #                2: end_index,
@@ -245,7 +247,7 @@ sub play_FILTER {
 
     ### play the block
     my $out = '';
-    eval { $self->play_tree($sub_tree, \$out) };
+    eval { local $self->{'STREAM'} = undef; $self->play_tree($sub_tree, \$out) };
     die $@ if $@ && ! UNIVERSAL::can($@, 'type'); # TODO - shouldn't they all die ?
 
     $out = $self->play_expr([[undef, '-temp-', $out], 0, '|', @$filter]);
@@ -482,7 +484,10 @@ sub play_PERL {
     ### fill in any variables
     my $perl = $node->[4] || return;
     my $out  = '';
-    $self->play_tree($perl, \$out);
+    {
+        local $self->{'STREAM'} = undef;
+        $self->play_tree($perl, \$out);
+    };
     $out = $1 if $out =~ /^(.+)$/s; # blatant untaint - shouldn't use perl anyway
 
     ### try the code
@@ -610,7 +615,10 @@ sub play_RAWPERL {
     ### fill in any variables
     my $tree = $node->[4] || return;
     my $perl  = '';
-    $self->play_tree($tree, \$perl);
+    {
+        local $self->{'STREAM'} = undef;
+        $self->play_tree($tree, \$perl);
+    }
     $perl = $1 if $perl =~ /^(.+)$/s; # blatant untaint - shouldn't use perl anyway
 
     ### try the code
@@ -647,6 +655,7 @@ sub play_SET {
             my $sub_tree = $node->[4];
             $sub_tree = $sub_tree->[0]->[4] if $sub_tree->[0] && $sub_tree->[0]->[0] eq 'BLOCK';
             $val = '';
+            local $self->{'STREAM'} = undef;
             $self->play_tree($sub_tree, \$val);
         } else { # normal var
             $val = $self->play_expr($val);
@@ -919,12 +928,18 @@ sub play_WRAPPER {
     my ($named, @files) = @$args;
 
     my $out = '';
-    $self->play_tree($sub_tree, \$out);
-
-    foreach my $name (reverse @files) {
-        local $self->{'_vars'}->{'content'} = $out;
+    {
+        local $self->{'STREAM'} = undef;
+        $self->play_tree($sub_tree, \$out);
+        foreach my $name (reverse @files) {
+            local $self->{'_vars'}->{'content'} = $out;
+            $out = '';
+            $DIRECTIVES->{'INCLUDE'}->($self, [$named, $name], $node, \$out);
+        }
+    }
+    if ($self->{'STREAM'}) {
+        print $out;
         $out = '';
-        $DIRECTIVES->{'INCLUDE'}->($self, [$named, $name], $node, \$out);
     }
 
     $$out_ref .= $out;
